"""Contract adapters for IQToolkit Analyzer."""

from .compatibility import (
    build_contract_results_from_legacy_payload,
    serialize_contract_results,
)

__all__ = [
    "build_contract_results_from_legacy_payload",
    "serialize_contract_results",
]
